use crate::{
    config::{InstallConfig, InstallMode},
    linux::{arch_chroot, systemd_service_enable},
    pkg::install_pkgs,
};

pub fn setup_virtualization(conf: &InstallConfig) {
    let user_conf = if let Some(user_conf) = &conf.user {
        user_conf.clone()
    } else {
        Vec::new()
    };

    install_pkgs(&["libvirt"]);

    if matches!(conf.general.mode, InstallMode::Desktop) {
        install_pkgs(&["virt-manager"]);
    }

    systemd_service_enable("libvirtd.service");

    for user in user_conf {
        if user.virtualization.unwrap_or_default() {
            arch_chroot(
                &vec!["usermod", "-a", "-G", "libvirt", user.name.as_str()],
                None,
                false,
            );
        }
    }
}

pub fn setup_vm() {
    // TODO : Install guest tools if in virt with  systemd-detect-virt 
}
